==> hlw-core-0.0.2-20250711.025037-103-sources.jar: cn/gtmap/hlw/core/repository/HlwPzPzxRepository.java <==
package cn.gtmap.hlw.core.repository;

import cn.gtmap.hlw.core.model.HlwPzPzx;

import java.util.List;

/**
 * 配置项表(HlwPzPzx)表数据库访问层
 *
 * @author makejava
 * @since 2023-06-08 16:06:48
 */
public interface HlwPzPzxRepository {

    /**
     * 通过ID查询单条数据
     *
     * @param pzxid 主键
     * @return 实例对象
     */
    HlwPzPzx get(String pzxid);

    /**
     * 通过ID查询单条数据
     *
     * @param pzxKey
     * @return 实例对象
     */
    HlwPzPzx getHlwPzPzxByPzxKey(String pzxKey);

    /**
     * 通过ID查询单条数据
     *
     * @param pzxKey
     * @return 实例对象
     */
    String getHlwPzPzxValueByPzxKey(String pzxKey);

    /**
     * 通过ID查询单条数据
     *
     * @param pzxKey
     * @param defaultValue 默认值
     * @return 实例对象
     */
    String getHlwPzPzxValueByPzxKey(String pzxKey, String defaultValue);

    /**
     * 新增数据
     *
     * @param hlwPzPzx 实例对象
     * @return 影响行数
     */
    void save(HlwPzPzx hlwPzPzx);

    /**
     * 修改数据
     *
     * @param hlwPzPzx 实例对象
     * @return 影响行数
     */
    void update(HlwPzPzx hlwPzPzx);

    /**
     * 查询PC端配置
     * @param pzPzx
     * @return
     */
    List<HlwPzPzx> pcConfig(HlwPzPzx pzPzx,List<String> pzxKeyList);

    /**
     * 加载所有配置项
     * @return
     */
    List<HlwPzPzx> getHlwPzPzxAll();

    /**
     * 根据key值和区域代码查询
     * @param pzxKey
     * @param qydm
     * @return:String
     * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
    */
    String getHlwPzPzxValueByPzxKeyAndQydm(String pzxKey, String qydm);

    Boolean checkHlwPzByPzxKeyAndValue(String pzxKey, String checkValue);
}

==> hlw-core-0.0.2-20251205.085720-174-sources.jar: cn/gtmap/hlw/core/repository/HlwPzPzxRepository.java <==
package cn.gtmap.hlw.core.repository;

import cn.gtmap.hlw.core.base.PageInfo;
import cn.gtmap.hlw.core.dto.pzx.HlwPzxQueryDTO;
import cn.gtmap.hlw.core.model.HlwPzPzx;

import java.util.List;

/**
 * 配置项表(HlwPzPzx)表数据库访问层
 *
 * @author makejava
 * @since 2023-06-08 16:06:48
 */
public interface HlwPzPzxRepository {

    /**
     * 通过ID查询单条数据
     *
     * @param pzxid 主键
     * @return 实例对象
     */
    HlwPzPzx get(String pzxid);

    /**
     * 通过ID查询单条数据
     *
     * @param pzxKey
     * @return 实例对象
     */
    HlwPzPzx getHlwPzPzxByPzxKey(String pzxKey);

    /**
     * 通过ID查询单条数据
     *
     * @param pzxKey
     * @return 实例对象
     */
    String getHlwPzPzxValueByPzxKey(String pzxKey);

    /**
     * 通过ID查询单条数据
     *
     * @param pzxKey
     * @param defaultValue 默认值
     * @return 实例对象
     */
    String getHlwPzPzxValueByPzxKey(String pzxKey, String defaultValue);

    /**
     * 新增数据
     *
     * @param hlwPzPzx 实例对象
     * @return 影响行数
     */
    void save(HlwPzPzx hlwPzPzx);

    /**
     * 修改数据
     *
     * @param hlwPzPzx 实例对象
     * @return 影响行数
     */
    void update(HlwPzPzx hlwPzPzx);

    /**
     * 查询PC端配置
     * @param pzPzx
     * @return
     */
    List<HlwPzPzx> pcConfig(HlwPzPzx pzPzx,List<String> pzxKeyList);

    /**
     * 加载所有配置项
     * @return
     */
    List<HlwPzPzx> getHlwPzPzxAll();

    /**
     * 根据key值和区域代码查询
     * @param pzxKey
     * @param qydm
     * @return:String
     * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
    */
    String getHlwPzPzxValueByPzxKeyAndQydm(String pzxKey, String qydm);

    Boolean checkHlwPzByPzxKeyAndValue(String pzxKey, String checkValue);

    /**
     * 查询所有配置项
     *
     * @return 配置项列表
     */
    List<HlwPzPzx> all();

    /**
     * 根据配置项Key集合查询配置
     *
     * @param pzxKeyList key集合
     * @return 配置项列表
     */
    List<HlwPzPzx> listByPzxKey(List<String> pzxKeyList);

    /**
     * 删除配置项
     *
     * @param pzxid 主键
     */
    void delete(String pzxid);

    /**
     * 重置配置项状态
     */
    void updatePzxzt();

    /**
     * 分页查询配置项
     *
     * @param queryDTO 查询参数
     * @return 分页结果
     */
    PageInfo<HlwPzPzx> page(HlwPzxQueryDTO queryDTO);

    /**
     * 保存或更新配置项
     *
     * @param hlwPzPzx 配置项
     */
    void saveOrUpdate(HlwPzPzx hlwPzPzx);

    /**
     * 批量保存或更新配置项
     *
     * @param hlwPzPzxList 配置项集合
     */
    void saveOrUpdateBatch(List<HlwPzPzx> hlwPzPzxList);
}
